==> lxqt-powermanagement_2.0.0.orig.tar.xz: lxqt-powermanagement-2.0.0/config/translations/lxqt-config-powermanagement_pa.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pa">
<context>
    <name>BatteryWatcherSettings</name>
    <message>
        <location filename="../batterywatchersettings.ui" line="14"/>
        <source>Battery Watcher Settings</source>
        <translation>ਬੈਟਰੀ ਨਿਗਰਾਨ ਸੈਟਿੰਗਾਂ</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="26"/>
        <source>E&amp;nable Battery Watcher</source>
        <translation>ਬੈਟਰੀ ਨਿਗਰਾਨ ਸਮਰੱਥ ਕਰੋ(&amp;n)</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="54"/>
        <source>Warning:</source>
        <translation>ਸਾਵਧਾਨ:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="67"/>
        <source> seconds</source>
        <translation> ਸਕਿੰਟ</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="77"/>
        <source>Level is low at:</source>
        <translation>ਪੱਧਰ ਘੱਟ ਹੈ:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="90"/>
        <source> %</source>
        <translation> %</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="111"/>
        <source>Icon:</source>
        <translation>ਆਈਕਾਨ:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="121"/>
        <location filename="../batterywatchersettings.cpp" line="104"/>
        <source>Preview</source>
        <translation>ਝਲਕ</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="158"/>
        <source>Charging</source>
        <translation>ਚਾਰਜ ਹੋ ਰਹੀ ਹੈ</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="196"/>
        <source>Discharging</source>
        <translation>ਡਿਸ-ਚਾਰਜ ਹੋ ਰਹੀ ਹੈ</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="41"/>
        <source>When power is low then:</source>
        <translation>ਜਦੋਂ ਪਾਵਰ ਘੱਟ ਹੋਵੇ ਤਾਂ:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="97"/>
        <source>Show icon:</source>
        <translation>ਆਈਕਾਨ ਦਿਖਾਓ:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="41"/>
        <source>from theme</source>
        <comment>icons</comment>
        <translation>ਥੀਮ ਤੋਂ</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="42"/>
        <source>Circle</source>
        <comment>icons</comment>
        <translation>ਚੱਕਰ</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="43"/>
        <source>Circle with percentage</source>
        <comment>icons</comment>
        <translation>ਫੀਸਦੀ ਨਾਲ ਚੱਕਰ</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="44"/>
        <source>Battery with percentage and background</source>
        <comment>icons</comment>
        <translation>ਫੀਸਦੀ ਅਤੇ ਬੈਕਗਰਾਊਂਡ ਨਾਲ ਬੈਟਰੀ</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="45"/>
        <source>Battery with percentage</source>
        <comment>icons</comment>
        <translation>ਫੀਸਦੀ ਨਾਲ ਬੈਟਰੀ</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="104"/>
        <source>built in</source>
        <translation>ਬਿਲਟ-ਇਨ</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="109"/>
        <source>Level: %1%</source>
        <translation>ਪੱਧਰ: %1%</translation>
    </message>
</context>
<context>
    <name>IdlenessWatcherSettings</name>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="17"/>
        <source>Enab&amp;le Idleness Watcher</source>
        <translation>ਵੇਹਲੇ ਹੋਣ ਲਈ ਨਿਗਰਾਨ ਸਮਰੱਥ(&amp;l)</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="151"/>
        <source>Idle time:</source>
        <translation>ਵੇਹਲਾ ਸਮਾਂ:</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="122"/>
        <source>Enable Backlight Change</source>
        <translation>ਬੈਕਲਾਈਟ ਬਦਲਣਾ ਸਮਰੱਥ</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="83"/>
        <source>When idle on Battery:</source>
        <translation>ਜਦੋਂ ਬੈਟਰੀ ਉੱਤੇ ਵੇਹਲਾ ਹੋਵੇ:</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="90"/>
        <source>Battery Idle time:</source>
        <translation>ਬੈਟਰੀ ਵੇਹਲਾ ਸਮਾਂ:</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="131"/>
        <source>Backlight (%):</source>
        <translation>ਬੈਕਲਾਈਟ (%):</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="158"/>
        <source>Minutes:Seconds</source>
        <translation>ਮਿੰਟ:ਸਕਿੰਟ</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="76"/>
        <location filename="../idlenesswatchersettings.ui" line="110"/>
        <location filename="../idlenesswatchersettings.ui" line="178"/>
        <source>mm:ss</source>
        <translation>mm:ss</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="34"/>
        <source>When idle on AC:</source>
        <translation>ਜਦ AC ਉੱਤੇ ਵੇਹਲਾ ਹੋਵੇ:</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="53"/>
        <source>AC Idle time:</source>
        <translation>AC ਉੱਤੇ ਵੇਹਲ ਸਮਾਂ:</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="63"/>
        <location filename="../idlenesswatchersettings.ui" line="97"/>
        <source>Minutes:Seconds (min: 01:30)</source>
        <translation>ਮਿੰਟ:ਸਕਿੰਟ (ਮਿੰਟ: 01:30)</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="185"/>
        <source>Check backlight</source>
        <translation>ਬੈਕਲਾਈਟ ਜਾਂਚੋ</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="192"/>
        <source>On battery discharging </source>
        <translation>ਜਦੋਂ ਬੈਟਰੀ ਡਿਸ-ਚਾਰਜ ਹੋ ਰਹੀ ਹੋਵੇ </translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="208"/>
        <source>Disable idleness checks when fullscreen</source>
        <translation>ਜਦੋਂ ਪੂਰੀ ਸਕਰੀਨ ਹੋਵੇ ਤਾਂ ਵੇਹਲੇ ਹੋਣ ਦੀ ਜਾਂਚ ਅਸਮਰੱਥ ਕਰੋ</translation>
    </message>
</context>
<context>
    <name>LidWatcherSettings</name>
    <message>
        <location filename="../lidwatchersettings.ui" line="23"/>
        <source>Enable &amp;Lid Watcher</source>
        <translation>&amp;Lid ਨਿਗਰਾਨ ਸਮਰੱਥ</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="38"/>
        <source>Action when lid is closed:</source>
        <translation>ਜਦੋਂ lid ਬੰਦ ਹੋਵੇ ਤਾਂ ਕਾਰਵਾਈ:</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="50"/>
        <location filename="../lidwatchersettings.ui" line="115"/>
        <source>On Battery:</source>
        <translation>ਬੈਟਰੀ ਉੱਤੇ:</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="58"/>
        <source>Nothing</source>
        <translation>ਕੁਝ ਨਹੀਂ</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="63"/>
        <source>Suspend</source>
        <translation>ਸਸਪੈਂਡ</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="68"/>
        <source>Hibernate</source>
        <translation>ਹਾਈਬਰਨੇਟ</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="73"/>
        <source>Shut down</source>
        <translation>ਬੰਦ ਕਰੋ</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="81"/>
        <location filename="../lidwatchersettings.ui" line="125"/>
        <source>On AC:</source>
        <translation>AC ਉੱਤੇ:</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="94"/>
        <source>When &amp;using external monitor</source>
        <translation>ਜਦੋਂ ਬਾਹਰੀ ਮਾਨੀਟਰ ਵਰਤਿਆ ਜਾਂਦਾ ਹੈ(&amp;u)</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="37"/>
        <source>Power Management Settings</source>
        <translation>ਪਾਵਰ ਇੰਤਜ਼ਾਮ ਸੈਟਿੰਗਾਂ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="40"/>
        <source>Battery</source>
        <translation>ਬੈਟਰੀ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="44"/>
        <source>Lid</source>
        <translation>Lid</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="48"/>
        <source>Idle</source>
        <translation>ਵੇਹਲਾ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="52"/>
        <source>Power keys</source>
        <translation>ਪਾਵਰ ਸਵਿੱਚਾਂ</translation>
    </message>
</context>
<context>
    <name>PowerKeysSettings</name>
    <message>
        <location filename="../powerkeyssettings.ui" line="14"/>
        <source>Form</source>
        <translation>ਫਾਰਮ</translation>
    </message>
    <message>
        <location filename="../powerkeyssettings.ui" line="20"/>
        <source>Handle Power Keys</source>
        <translation>ਪਾਵਰ ਸਵਿੱਚਾਂ ਨਾਲ ਕੰਮ</translation>
    </message>
    <message>
        <location filename="../powerkeyssettings.ui" line="26"/>
        <source>Power Key Action:</source>
        <translation>ਪਾਵਰ ਸਵਿੱਚ ਕਾਰਵਾਈ:</translation>
    </message>
    <message>
        <location filename="../powerkeyssettings.ui" line="42"/>
        <source>Suspend Key Action:</source>
        <translation>ਸਸਪੈਂਡ ਸਵਿੱਚ ਕਾਰਵਾਈ:</translation>
    </message>
    <message>
        <location filename="../powerkeyssettings.ui" line="49"/>
        <source>Hibernate Key Action:</source>
        <translation>ਹਾਈਬਰਨੇਟ ਸਵਿੱਚ ਕਾਰਵਾਈ:</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../helpers.cpp" line="35"/>
        <source>Nothing</source>
        <translation>ਕੁਝ ਨਹੀਂ</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="38"/>
        <source>Ask</source>
        <translation>ਪੁੱਛੋ</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="40"/>
        <source>Lock screen</source>
        <translation>ਸਕਰੀਨ ਲਾਕ</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="41"/>
        <source>Suspend</source>
        <translation>ਸਸਪੈਂਡ</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="42"/>
        <source>Hibernate</source>
        <translation>ਹਾਈਬਰਨੇਟ</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="43"/>
        <source>Shutdown</source>
        <translation>ਬੰਦ ਕਰੋ</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="44"/>
        <source>Turn Off monitor(s)</source>
        <translation>ਮਾਨੀਟਰ ਬੰਦ ਕਰੋ</translation>
    </message>
</context>
</TS>

==> lxqt-powermanagement_2.2.1.orig.tar.xz: lxqt-powermanagement-2.2.1/config/translations/lxqt-config-powermanagement_pa.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pa">
<context>
    <name>BatteryWatcherSettings</name>
    <message>
        <location filename="../batterywatchersettings.ui" line="14"/>
        <source>Battery Watcher Settings</source>
        <translation>ਬੈਟਰੀ ਨਿਗਰਾਨ ਸੈਟਿੰਗਾਂ</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="26"/>
        <source>E&amp;nable Battery Watcher</source>
        <translation>ਬੈਟਰੀ ਨਿਗਰਾਨ ਸਮਰੱਥ ਕਰੋ(&amp;n)</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="54"/>
        <source>Warning:</source>
        <translation>ਸਾਵਧਾਨ:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="67"/>
        <source> seconds</source>
        <translation> ਸਕਿੰਟ</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="77"/>
        <source>Level is low at:</source>
        <translation>ਪੱਧਰ ਘੱਟ ਹੈ:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="90"/>
        <source> %</source>
        <translation> %</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="111"/>
        <source>Icon:</source>
        <translation>ਆਈਕਾਨ:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="121"/>
        <location filename="../batterywatchersettings.cpp" line="104"/>
        <source>Preview</source>
        <translation>ਝਲਕ</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="158"/>
        <source>Charging</source>
        <translation>ਚਾਰਜ ਹੋ ਰਹੀ ਹੈ</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="196"/>
        <source>Discharging</source>
        <translation>ਡਿਸ-ਚਾਰਜ ਹੋ ਰਹੀ ਹੈ</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="41"/>
        <source>When power is low then:</source>
        <translation>ਜਦੋਂ ਪਾਵਰ ਘੱਟ ਹੋਵੇ ਤਾਂ:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="97"/>
        <source>Show icon:</source>
        <translation>ਆਈਕਾਨ ਦਿਖਾਓ:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="41"/>
        <source>from theme</source>
        <comment>icons</comment>
        <translation>ਥੀਮ ਤੋਂ</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="42"/>
        <source>Circle</source>
        <comment>icons</comment>
        <translation>ਚੱਕਰ</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="43"/>
        <source>Circle with percentage</source>
        <comment>icons</comment>
        <translation>ਫੀਸਦੀ ਨਾਲ ਚੱਕਰ</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="44"/>
        <source>Battery with percentage and background</source>
        <comment>icons</comment>
        <translation>ਫੀਸਦੀ ਅਤੇ ਬੈਕਗਰਾਊਂਡ ਨਾਲ ਬੈਟਰੀ</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="45"/>
        <source>Battery with percentage</source>
        <comment>icons</comment>
        <translation>ਫੀਸਦੀ ਨਾਲ ਬੈਟਰੀ</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="104"/>
        <source>built in</source>
        <translation>ਬਿਲਟ-ਇਨ</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="109"/>
        <source>Level: %1%</source>
        <translation>ਪੱਧਰ: %1%</translation>
    </message>
</context>
<context>
    <name>IdlenessWatcherSettings</name>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="17"/>
        <source>Enab&amp;le Idleness Watcher</source>
        <translation>ਵੇਹਲੇ ਹੋਣ ਲਈ ਨਿਗਰਾਨ ਸਮਰੱਥ(&amp;l)</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="151"/>
        <source>Idle time:</source>
        <translation>ਵੇਹਲਾ ਸਮਾਂ:</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="122"/>
        <source>Enable Backlight Change</source>
        <translation>ਬੈਕਲਾਈਟ ਬਦਲਣਾ ਸਮਰੱਥ</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="83"/>
        <source>When idle on Battery:</source>
        <translation>ਜਦੋਂ ਬੈਟਰੀ ਉੱਤੇ ਵੇਹਲਾ ਹੋਵੇ:</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="90"/>
        <source>Battery Idle time:</source>
        <translation>ਬੈਟਰੀ ਵੇਹਲਾ ਸਮਾਂ:</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="131"/>
        <source>Backlight (%):</source>
        <translation>ਬੈਕਲਾਈਟ (%):</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="158"/>
        <source>Minutes:Seconds</source>
        <translation>ਮਿੰਟ:ਸਕਿੰਟ</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="76"/>
        <location filename="../idlenesswatchersettings.ui" line="110"/>
        <location filename="../idlenesswatchersettings.ui" line="178"/>
        <source>mm:ss</source>
        <translation>mm:ss</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="34"/>
        <source>When idle on AC:</source>
        <translation>ਜਦ AC ਉੱਤੇ ਵੇਹਲਾ ਹੋਵੇ:</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="53"/>
        <source>AC Idle time:</source>
        <translation>AC ਉੱਤੇ ਵੇਹਲ ਸਮਾਂ:</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="63"/>
        <location filename="../idlenesswatchersettings.ui" line="97"/>
        <source>Minutes:Seconds (min: 01:30)</source>
        <translation>ਮਿੰਟ:ਸਕਿੰਟ (ਮਿੰਟ: 01:30)</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="185"/>
        <source>Check backlight</source>
        <translation>ਬੈਕਲਾਈਟ ਜਾਂਚੋ</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="192"/>
        <source>On battery discharging </source>
        <translation>ਜਦੋਂ ਬੈਟਰੀ ਡਿਸ-ਚਾਰਜ ਹੋ ਰਹੀ ਹੋਵੇ </translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="208"/>
        <source>Disable idleness checks when fullscreen</source>
        <translation>ਜਦੋਂ ਪੂਰੀ ਸਕਰੀਨ ਹੋਵੇ ਤਾਂ ਵੇਹਲੇ ਹੋਣ ਦੀ ਜਾਂਚ ਅਸਮਰੱਥ ਕਰੋ</translation>
    </message>
</context>
<context>
    <name>LidWatcherSettings</name>
    <message>
        <location filename="../lidwatchersettings.ui" line="23"/>
        <source>Enable &amp;Lid Watcher</source>
        <translation>&amp;Lid ਨਿਗਰਾਨ ਸਮਰੱਥ</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="38"/>
        <source>Action when lid is closed:</source>
        <translation>ਜਦੋਂ lid ਬੰਦ ਹੋਵੇ ਤਾਂ ਕਾਰਵਾਈ:</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="50"/>
        <location filename="../lidwatchersettings.ui" line="115"/>
        <source>On Battery:</source>
        <translation>ਬੈਟਰੀ ਉੱਤੇ:</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="58"/>
        <source>Nothing</source>
        <translation>ਕੁਝ ਨਹੀਂ</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="63"/>
        <source>Suspend</source>
        <translation>ਸਸਪੈਂਡ</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="68"/>
        <source>Hibernate</source>
        <translation>ਹਾਈਬਰਨੇਟ</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="73"/>
        <source>Shut down</source>
        <translation>ਬੰਦ ਕਰੋ</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="81"/>
        <location filename="../lidwatchersettings.ui" line="125"/>
        <source>On AC:</source>
        <translation>AC ਉੱਤੇ:</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="94"/>
        <source>When &amp;using external monitor</source>
        <translation>ਜਦੋਂ ਬਾਹਰੀ ਮਾਨੀਟਰ ਵਰਤਿਆ ਜਾਂਦਾ ਹੈ(&amp;u)</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="37"/>
        <source>Power Management Settings</source>
        <translation>ਪਾਵਰ ਇੰਤਜ਼ਾਮ ਸੈਟਿੰਗਾਂ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="40"/>
        <source>Battery</source>
        <translation>ਬੈਟਰੀ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="44"/>
        <source>Lid</source>
        <translation>Lid</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="48"/>
        <source>Idle</source>
        <translation>ਵੇਹਲਾ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="52"/>
        <source>Power keys</source>
        <translation>ਪਾਵਰ ਸਵਿੱਚਾਂ</translation>
    </message>
</context>
<context>
    <name>PowerKeysSettings</name>
    <message>
        <location filename="../powerkeyssettings.ui" line="14"/>
        <source>Form</source>
        <translation>ਫਾਰਮ</translation>
    </message>
    <message>
        <location filename="../powerkeyssettings.ui" line="20"/>
        <source>Handle Power Keys</source>
        <translation>ਪਾਵਰ ਸਵਿੱਚਾਂ ਨਾਲ ਕੰਮ</translation>
    </message>
    <message>
        <location filename="../powerkeyssettings.ui" line="26"/>
        <source>Power Key Action:</source>
        <translation>ਪਾਵਰ ਸਵਿੱਚ ਕਾਰਵਾਈ:</translation>
    </message>
    <message>
        <location filename="../powerkeyssettings.ui" line="42"/>
        <source>Suspend Key Action:</source>
        <translation>ਸਸਪੈਂਡ ਸਵਿੱਚ ਕਾਰਵਾਈ:</translation>
    </message>
    <message>
        <location filename="../powerkeyssettings.ui" line="49"/>
        <source>Hibernate Key Action:</source>
        <translation>ਹਾਈਬਰਨੇਟ ਸਵਿੱਚ ਕਾਰਵਾਈ:</translation>
    </message>
    <message>
        <location filename="../powerkeyssettings.cpp" line="48"/>
        <source>Note: Under Wayland, power keys are configured by the compositor instead.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../helpers.cpp" line="35"/>
        <source>Nothing</source>
        <translation>ਕੁਝ ਨਹੀਂ</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="38"/>
        <source>Ask</source>
        <translation>ਪੁੱਛੋ</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="40"/>
        <source>Lock screen</source>
        <translation>ਸਕਰੀਨ ਲਾਕ</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="41"/>
        <source>Suspend</source>
        <translation>ਸਸਪੈਂਡ</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="42"/>
        <source>Hibernate</source>
        <translation>ਹਾਈਬਰਨੇਟ</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="43"/>
        <source>Shutdown</source>
        <translation>ਬੰਦ ਕਰੋ</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="44"/>
        <source>Turn Off monitor(s)</source>
        <translation>ਮਾਨੀਟਰ ਬੰਦ ਕਰੋ</translation>
    </message>
</context>
</TS>
